@@ -16,7 +16,7 @@
   GNU General Public License for more details.
 
 */
-/* $Id: command_reply.c,v 1.106.2.20 2005/05/09 09:59:49 priikone Exp $ */
+/* $Id: command_reply.c,v 1.106.2.21 2005/11/19 20:45:59 priikone Exp $ */
 
 #include "serverincludes.h"
 #include "server_internal.h"
@@ -331,7 +331,7 @@ silc_server_command_reply_whois_save(SilcServerCommandReplyContext cmd)
     if (server->server_type != SILC_ROUTER && !client->data.public_key) {
       SilcAttributePayload attr;
       SilcAttributeObjPk pk;
-      unsigned char f[20];
+      unsigned char f[SILC_HASH_MAXLEN];
       SilcDList attrs = silc_attribute_payload_parse(tmp, len);
 
       SILC_LOG_DEBUG(("Take client public key from attributes"));
