@@ -20,7 +20,7 @@
  * These are general utility functions that doesn't belong to any specific
  * group of routines.
  */
-/* $Id: silcunixutil.c,v 1.10.2.1 2005/04/30 15:31:27 priikone Exp $ */
+/* $Id: silcunixutil.c,v 1.10.2.2 2005/05/26 17:30:56 priikone Exp $ */
 
 #include "silcincludes.h"
 
@@ -98,7 +98,7 @@ int silc_string_regex_match(const char *regex, const char *string)
   regex_t preg;
   int ret = FALSE;
   
-  if (regcomp(&preg, regex, REG_NOSUB | REG_EXTENDED) < 0)
+  if (regcomp(&preg, regex, REG_NOSUB | REG_EXTENDED) != 0)
     return FALSE;
 
   if (regexec(&preg, string, 0, NULL, 0) == 0)
